.. _methods_freqs.rst:

Individual frequencies
**********************



.. _methods_freqs_dnufrac:

Frequency constraint
====================
 (equivalent to a :ref:`prior <controls_fit_priors>`). As the sign of the correction is known, this fraction applies to the upper limit of the :math:`\nu_\text{mod} - \nu_\text{obs}` difference, while the lower limit is limited to :math:`-3\sigma_\nu`.


.. _methods_freqs_exclude:

Excluding frequencies
=====================



.. _methods_freqs_matching:

Frequency matching
==================
